@@ -18,6 +18,8 @@
 #include <string>
 #include <cstring>
 #include <sstream>
+#include <thread>
+#include <chrono>
 
 using namespace std;
 using namespace ixion;
@@ -89,6 +91,7 @@ void test_name_resolver_excel_a1()
     cxt.append_sheet(IXION_ASCII("Two"), 1048576, 1024);
     cxt.append_sheet(IXION_ASCII("Three"), 1048576, 1024);
     cxt.append_sheet(IXION_ASCII("A B C"), 1048576, 1024); // name with space
+    cxt.append_sheet(IXION_ASCII("'quote'"), 1048576, 1024); // quoted name
     auto resolver = formula_name_resolver::get(formula_name_resolver_t::excel_a1, &cxt);
     assert(resolver);
 
@@ -118,6 +121,7 @@ void test_name_resolver_excel_a1()
         { "Two!$B$10", true },
         { "Three!CFD234", true },
         { "'A B C'!Z12", true },
+        { "'''quote'''!Z12", true },
         { 0, false }
     };
 
@@ -125,8 +129,8 @@ void test_name_resolver_excel_a1()
     {
         const char* p = names[i].name;
         string name_a1(p);
-        formula_name_type res = resolver->resolve(&name_a1[0], name_a1.size(), abs_address_t());
-        if (res.type != formula_name_type::cell_reference)
+        formula_name_t res = resolver->resolve(&name_a1[0], name_a1.size(), abs_address_t());
+        if (res.type != formula_name_t::cell_reference)
         {
             cerr << "failed to resolve cell address: " << name_a1 << endl;
             assert(false);
@@ -157,8 +161,8 @@ void test_name_resolver_excel_a1()
     for (size_t i = 0; range_tests[i].name; ++i)
     {
         string name_a1(range_tests[i].name);
-        formula_name_type res = resolver->resolve(&name_a1[0], name_a1.size(), abs_address_t());
-        assert(res.type == formula_name_type::range_reference);
+        formula_name_t res = resolver->resolve(&name_a1[0], name_a1.size(), abs_address_t());
+        assert(res.type == formula_name_t::range_reference);
         assert(res.range.first.sheet == range_tests[i].sheet1);
         assert(res.range.first.row == range_tests[i].row1);
         assert(res.range.first.col == range_tests[i].col1);
@@ -167,14 +171,14 @@ void test_name_resolver_excel_a1()
         assert(res.range.last.col == range_tests[i].col2);
     }
 
-    formula_name_type res = resolver->resolve("B1", 2, abs_address_t(0,1,1));
-    assert(res.type == formula_name_type::cell_reference);
+    formula_name_t res = resolver->resolve("B1", 2, abs_address_t(0,1,1));
+    assert(res.type == formula_name_t::cell_reference);
     assert(res.address.sheet == 0);
     assert(res.address.row == -1);
     assert(res.address.col == 0);
 
     res = resolver->resolve("B2:B4", 5, abs_address_t(0,0,3));
-    assert(res.type == formula_name_type::range_reference);
+    assert(res.type == formula_name_t::range_reference);
     assert(res.range.first.sheet == 0);
     assert(res.range.first.row == 1);
     assert(res.range.first.col == -2);
@@ -184,19 +188,19 @@ void test_name_resolver_excel_a1()
 
     // Parse name without row index.
     struct {
-        const char* name; formula_name_type::name_type type;
+        const char* name; formula_name_t::name_type type;
     } name_tests[] = {
-        { "H:H", formula_name_type::range_reference },
-        { "ABC", formula_name_type::named_expression },
-        { "H", formula_name_type::named_expression },
-        { "MAX", formula_name_type::function },
-        { 0, formula_name_type::invalid }
+        { "H:H", formula_name_t::range_reference },
+        { "ABC", formula_name_t::named_expression },
+        { "H", formula_name_t::named_expression },
+        { "MAX", formula_name_t::function },
+        { 0, formula_name_t::invalid }
     };
 
     for (size_t i = 0; name_tests[i].name; ++i)
     {
         string name_a1(name_tests[i].name);
-        formula_name_type res = resolver->resolve(&name_a1[0], name_a1.size(), abs_address_t());
+        formula_name_t res = resolver->resolve(&name_a1[0], name_a1.size(), abs_address_t());
         assert(res.type == name_tests[i].type);
     }
 }
@@ -252,11 +256,11 @@ void test_name_resolver_table_excel_a1()
     {
         cout << "* table reference: " << tests[i].exp << endl;
         abs_address_t pos(tests[i].sheet, tests[i].row, tests[i].col);
-        formula_name_type res = resolver->resolve(tests[i].exp, tests[i].len, pos);
-        if (res.type != formula_name_type::table_reference)
+        formula_name_t res = resolver->resolve(tests[i].exp, tests[i].len, pos);
+        if (res.type != formula_name_t::table_reference)
             assert(!"table reference expected.");
 
-        formula_name_type::table_type table = res.table;
+        formula_name_t::table_type table = res.table;
         string_id_t table_name = cxt.get_string_identifier(table.name, table.name_length);
         string_id_t column_first = cxt.get_string_identifier(table.column_first, table.column_first_length);
         string_id_t column_last = cxt.get_string_identifier(table.column_last, table.column_last_length);
@@ -315,8 +319,8 @@ void test_name_resolver_excel_r1c1()
     {
         const char* p = single_ref_names[i].name;
         string name_r1c1(p);
-        formula_name_type res = resolver->resolve(name_r1c1.data(), name_r1c1.size(), abs_address_t());
-        if (res.type != formula_name_type::cell_reference)
+        formula_name_t res = resolver->resolve(name_r1c1.data(), name_r1c1.size(), abs_address_t());
+        if (res.type != formula_name_t::cell_reference)
         {
             cerr << "failed to resolve cell address: " << name_r1c1 << endl;
             assert(false);
@@ -356,8 +360,8 @@ void test_name_resolver_excel_r1c1()
     {
         const char* p = invalid_address[i];
         string name_r1c1(p);
-        formula_name_type res = resolver->resolve(name_r1c1.data(), name_r1c1.size(), abs_address_t());
-        if (res.type != formula_name_type::invalid)
+        formula_name_t res = resolver->resolve(name_r1c1.data(), name_r1c1.size(), abs_address_t());
+        if (res.type != formula_name_t::invalid)
         {
             cerr << "address " << name_r1c1 << " is expected to be invalid." << endl;
             assert(false);
@@ -376,8 +380,8 @@ void test_name_resolver_excel_r1c1()
     {
         const char* p = valid_address[i];
         string name_r1c1(p);
-        formula_name_type res = resolver->resolve(name_r1c1.data(), name_r1c1.size(), abs_address_t());
-        if (res.type != formula_name_type::cell_reference)
+        formula_name_t res = resolver->resolve(name_r1c1.data(), name_r1c1.size(), abs_address_t());
+        if (res.type != formula_name_t::cell_reference)
         {
             cerr << "address " << name_r1c1 << " is expected to be valid." << endl;
             assert(false);
@@ -415,9 +419,9 @@ void test_name_resolver_excel_r1c1()
     {
         string name_r1c1(range_tests[i].name);
         cout << "Parsing " << name_r1c1 << endl;
-        formula_name_type res = resolver->resolve(&name_r1c1[0], name_r1c1.size(), abs_address_t());
+        formula_name_t res = resolver->resolve(&name_r1c1[0], name_r1c1.size(), abs_address_t());
 
-        assert(res.type == formula_name_type::range_reference);
+        assert(res.type == formula_name_t::range_reference);
 
         assert(res.range.first.sheet == range_tests[i].sheet1);
         assert(res.range.first.row == range_tests[i].row1);
@@ -453,8 +457,8 @@ void test_name_resolver_excel_r1c1()
     {
         const char* p = range_ref_names[i].name;
         string name_r1c1(p);
-        formula_name_type res = resolver->resolve(&name_r1c1[0], name_r1c1.size(), abs_address_t());
-        if (res.type != formula_name_type::range_reference)
+        formula_name_t res = resolver->resolve(&name_r1c1[0], name_r1c1.size(), abs_address_t());
+        if (res.type != formula_name_t::range_reference)
         {
             cerr << "failed to resolve range address: " << name_r1c1 << endl;
             assert(false);
@@ -518,8 +522,8 @@ void test_name_resolver_odff()
     {
         const char* p = single_ref_names[i].name;
         string name_a1(p);
-        formula_name_type res = resolver->resolve(&name_a1[0], name_a1.size(), abs_address_t());
-        if (res.type != formula_name_type::cell_reference)
+        formula_name_t res = resolver->resolve(&name_a1[0], name_a1.size(), abs_address_t());
+        if (res.type != formula_name_t::cell_reference)
         {
             cerr << "failed to resolve cell address: " << name_a1 << endl;
             assert(false);
@@ -547,8 +551,8 @@ void test_name_resolver_odff()
     {
         const char* p = range_ref_names[i].name;
         string name_a1(p);
-        formula_name_type res = resolver->resolve(&name_a1[0], name_a1.size(), abs_address_t());
-        if (res.type != formula_name_type::range_reference)
+        formula_name_t res = resolver->resolve(&name_a1[0], name_a1.size(), abs_address_t());
+        if (res.type != formula_name_t::range_reference)
         {
             cerr << "failed to resolve range address: " << name_a1 << endl;
             assert(false);
@@ -662,8 +666,8 @@ void test_function_name_resolution()
     {
         const char* name = valid_names[i];
         cout << "valid name: " << name << endl;
-        formula_name_type t = resolver->resolve(name, strlen(name), abs_address_t());
-        assert(t.type == formula_name_type::function);
+        formula_name_t t = resolver->resolve(name, strlen(name), abs_address_t());
+        assert(t.type == formula_name_t::function);
     }
 
     n = IXION_N_ELEMENTS(invalid_names);
@@ -671,8 +675,8 @@ void test_function_name_resolution()
     {
         const char* name = invalid_names[i];
         cout << "invalid name: " << name << endl;
-        formula_name_type t = resolver->resolve(name, strlen(name), abs_address_t());
-        assert(t.type != formula_name_type::function);
+        formula_name_t t = resolver->resolve(name, strlen(name), abs_address_t());
+        assert(t.type != formula_name_t::function);
     }
 }
 
@@ -696,7 +700,6 @@ void test_model_context_storage()
         assert(resolver);
 
         cxt.append_sheet(IXION_ASCII("test"), 1048576, 1024);
-        cxt.set_session_handler(NULL);
 
         // Test storage of numeric values.
         volatile double val = 0.1;
@@ -726,7 +729,6 @@ void test_model_context_storage()
         assert(resolver);
 
         cxt.append_sheet(IXION_ASCII("test"), 1048576, 1024);
-        cxt.set_session_handler(NULL);
         string exp = "1";
         cxt.set_formula_cell(abs_address_t(0,0,0), &exp[0], exp.size(), *resolver);
         cxt.set_formula_cell(abs_address_t(0,2,0), &exp[0], exp.size(), *resolver);
@@ -782,7 +784,6 @@ void test_volatile_function()
     assert(resolver);
 
     cxt.append_sheet(IXION_ASCII("test"), 1048576, 1024);
-    cxt.set_session_handler(NULL);
 
     dirty_formula_cells_t dirty_cells;
     modified_cells_t dirty_addrs;
@@ -830,7 +831,7 @@ void test_volatile_function()
     double t1 = cxt.get_numeric_value(abs_address_t(0,0,1));
 
     // Pause for 0.2 second.
-    global::sleep(200);
+    std::this_thread::sleep_for(std::chrono::milliseconds(200));
 
     // No modification, but B1 should still be flagged dirty.
     dirty_cells.clear();
